# telenvi
Some remote sensing tricks from telenvi master students.
Contain tools to work on satellites images. You can easily load georeferenced raster files in python, compute indices on it or extract their values, then make crops, resample and reprojection on it.

# GitHub repo
The code is available here : github.com/pyzak117/telenvi

# Dependancies
to work with telenvi you need thoses libraries:
  gdal
  numpy
  geopandas
  matplotlib

# Installation
pip install telenvi

# Use from a python script
You can download a tutorial to learn how to use the telenvi package here :
https://mega.nz/file/voNTUYrR#WHtp_stDGi-p3_TfUj9K_K76H56n0B1L0hGixMvVzkY
You will find a .rar archive containing jupyter notebooks and data to test the package.

The useful functions are stored into telenvi_tools module. You can access by typing this into a script:
*from telenvi import telenvi_tools*

# Contact
You can contact me at thibautduvanel2@hotmail.fr if you have any questions.
